@@ -252,7 +252,7 @@ Note: Inherited methods from class (({Object})) cannot be used as XML-RPC names,
 
 
 = History
-    $Id: client.rb,v 1.48 2002/01/08 23:00:52 michael Exp $
+    $Id: client.rb,v 1.49 2002/10/23 09:01:58 mneumann Exp $
 
 =end
 
@@ -472,6 +472,8 @@ module XMLRPC
         header["Authorization"] = @auth
       end
  
+      resp = nil
+
       if async
         # use a new HTTP object for each call 
         Net::HTTP.version_1_2
@@ -479,15 +481,19 @@ module XMLRPC
         http.use_ssl = @use_ssl if @use_ssl
         http.read_timeout = @timeout
         http.open_timeout = @timeout
+        
+        # post request
+        http.start {
+          resp = http.post2(@path, request, header) 
+        }
       else
         # reuse the HTTP object for each call => connection alive is possible
-        http = @http
+        
+        # post request
+        resp = @http.post2(@path, request, header) 
       end
   
-      # post request
-      resp = http.post2(@path, request, header) 
       data = resp.body
-      http.finish if async
 
       if resp.code == "401"
         # Authorization Required
