@@ -633,6 +633,14 @@ program.
 
 --- XMLRPC::Server#shutdown
     Stops and shuts the server down.
+
+--- XMLRPC::Server#set_valid_ip( *ip_addr )
+    Specifies the valid IP addresses that are allowed to connect to the server.
+    Each IP is either a (({String})) or a (({Regexp})).
+
+--- XMLRPC::Server#get_valid_ip
+    Return the via method ((<set_valid_ip|XMLRPC::Server#set_valid_ip>)) specified
+    valid IP addresses.
     
 =end
 
@@ -640,9 +648,8 @@ class Server < BasicServer
 
   def initialize(port=8080, host="127.0.0.1", maxConnections=4, stdlog=$stdout, audit=true, debug=true, *a)
     super(*a)
-
-    handler = self.method(:request_handler).to_proc
-    @server = ::HttpServer.new(handler, port, host, maxConnections, stdlog, audit, debug)
+    @server = ::HttpServer.new(self, port, host, maxConnections, stdlog, audit, debug)
+    @valid_ip = nil
   end
   
   def serve
@@ -660,8 +667,19 @@ class Server < BasicServer
     @server.shutdown
   end
 
- 
-  private
+  def set_valid_ip(*ip_addr)
+    if ip_addr.size == 1 and ip_addr[0].nil?
+      @valid_ip = nil
+    else
+      @valid_ip = ip_addr
+    end
+  end
+
+  def get_valid_ip
+    @valid_ip
+  end
+
+  # methods that get called by HttpServer ------------------------------------------
 
   def request_handler(request, response)
     $stderr.puts "in request_handler" if $DEBUG
@@ -703,6 +721,22 @@ class Server < BasicServer
     response.body = resp 
     
    end
+
+   ##
+   # Is called before request_handler and should return true if
+   # the client is allowed to connect to the server.
+   # `io' is a Socket object.
+   def ip_auth_handler(io)
+     if @valid_ip
+       client_ip = io.peeraddr[3]
+       @valid_ip.each { |ip|
+         return true if client_ip =~ ip
+       }
+       false
+     else
+       true
+     end
+   end
   
 end
 
@@ -750,6 +784,8 @@ class WEBrickServlet < BasicServer
     require "webrick/httpstatus"
   end
 
+  # deprecated from WEBrick/1.2.2. 
+  # but does not break anything.
   def require_path_info?
     false 
   end
@@ -797,6 +833,6 @@ end # module XMLRPC
 
 =begin
 = History
-    $Id: server.rb,v 1.47 2002/01/08 23:00:53 michael Exp $    
+    $Id: server.rb,v 1.50 2002/10/24 17:28:59 mneumann Exp $    
 =end
 
